# [QuGrad](README.md) Change Log

## Release 1.0.2

### Bug fixes
- Fixed bug in which the dependencies were not version pinned.

### Continuous Integration (CI) updates
- Added CI build support for Python 3.13
    - 3.14 will be added in the future when [TensorFlow](https://www.tensorflow.org) has 3.14 support

### Updated Metadata
- Corrected author names
- Added additional package classifiers
- Added version pins to `README.md`

## Release 1.0.1

- Bug fix in documentation generation
- Various typo corrections in the documentation

## Release 1.0.0

This is the initial release. Future changes to this release will be documented above.